[Zope3-checkins] CVS: Zope3/src/zope/app/form - interfaces.py:1.4

Garrett Smith garrett at mojave-corp.com
Fri May 7 15:40:10 EDT 2004


Update of /cvs-repository/Zope3/src/zope/app/form
In directory cvs.zope.org:/tmp/cvs-serv31404/src/zope/app/form

Modified Files:
	interfaces.py 
Log Message:
Renamed widget title and description to label and hint, respectively.


=== Zope3/src/zope/app/form/interfaces.py 1.3 => 1.4 ===
--- Zope3/src/zope/app/form/interfaces.py:1.3	Sun Apr 11 06:34:48 2004
+++ Zope3/src/zope/app/form/interfaces.py	Fri May  7 15:40:09 2004
@@ -102,15 +102,18 @@
 
         This must be unique within a set of widgets.""")
 
-    title = Attribute(
-        """The widget title.
+    label = Attribute(
+        """The widget label.
         
-        Title may be translated for the request.""")
+        Label may be translated for the request.""")
 
-    description = Attribute(
-        """The widget description.
+    hint = Attribute(
+        """A hint regarding the use of the widget.
         
-        Description may be translated for the request.""")
+        Hints are traditionally rendered using tooltips in GUIs, but may be
+        rendered differently depending on the UI implementation.
+        
+        Hint may be translated for the request.""")
         
     visible = Attribute(
         """A flag indicating whether or not the widget is visible.""")




More information about the Zope3-Checkins mailing list